.. :changelog:

Release History
===============

0.1.1b3 (2017-02-17)
^^^^^^^^^^^^^^^^^^^^

* Polish error messages for repository/credential commands
* Storage account sku validation
* Show commands return empty string with exit code 0 for 404 responses


0.1.1b2 (2017-01-30)
^^^^^^^^^^^^^^^^^^^^

* Support Python 3.6.
* Fix storage account name with capital letters.


0.1.1b1 (2017-01-17)
^^^^^^^^^^^^^^^^^^^^

* Update ACR SDK version to 0.1.1
* Add tty check before prompting for user input
* Enable storage account encryption by default


0.1.0b11 (2016-12-12)
^^^^^^^^^^^^^^^^^^^^^

* Preview release.
